@@ -130,7 +130,6 @@ struct ImageOpsContextManagerItem::Private
     {
         QUrl url = q->contextManager()->currentUrl();
         Document::Ptr doc = DocumentFactory::instance()->load(url);
-        doc->startLoadingFullImage();
         doc->waitUntilLoaded();
         if (doc->isEditable()) {
             return true;
@@ -300,7 +299,7 @@ void ImageOpsContextManagerItem::restoreDefaultImageViewTool()
     }
 
     AbstractRasterImageViewTool* tool = imageView->currentTool();
-    imageView->setCurrentTool(0);
+    imageView->setCurrentTool(nullptr);
     tool->deleteLater();
     d->mMainWindow->setDistractionFreeMode(false);
 }
