@@ -257,6 +257,7 @@ struct MainWindow::Private
 
         mCentralSplitter->setStretchFactor(0, 0);
         mCentralSplitter->setStretchFactor(1, 1);
+        mCentralSplitter->setChildrenCollapsible(false);
 
         mThumbnailView->setFocus();
 
@@ -321,6 +322,10 @@ struct MainWindow::Private
                 q, SLOT(goToPrevious()));
         connect(mViewMainPage, SIGNAL(nextImageRequested()),
                 q, SLOT(goToNext()));
+        connect(mViewMainPage, &ViewMainPage::openUrlRequested,
+                q, &MainWindow::openUrl);
+        connect(mViewMainPage, &ViewMainPage::openDirUrlRequested,
+                q, &MainWindow::openDirUrl);
 
         setupThumbnailBar(mViewMainPage->thumbnailBar());
     }
@@ -455,6 +460,7 @@ struct MainWindow::Private
         action->setIcon(QIcon::fromTheme("go-home"));
         action->setText(i18nc("@action", "Start Page"));
         action->setToolTip(i18nc("@info:tooltip", "Open the start page"));
+        actionCollection->setDefaultShortcuts(action, KStandardShortcut::home());
 
         mToggleSideBarAction = view->add<KToggleAction>("toggle_sidebar");
         connect(mToggleSideBarAction, &KToggleAction::triggered, q, &MainWindow::toggleSideBar);
@@ -531,7 +537,7 @@ struct MainWindow::Private
         InfoContextManagerItem* infoItem = new InfoContextManagerItem(mContextManager);
 
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-        SemanticInfoContextManagerItem* semanticInfoItem = 0;
+        SemanticInfoContextManagerItem* semanticInfoItem = nullptr;
         semanticInfoItem = new SemanticInfoContextManagerItem(mContextManager, actionCollection, mViewMainPage);
 #endif
 
@@ -767,6 +773,21 @@ struct MainWindow::Private
         }
     }
 
+    void loadSplitterConfig()
+    {
+        const QList<int> sizes = GwenviewConfig::sideBarSplitterSizes();
+        if (!sizes.isEmpty()) {
+            mCentralSplitter->setSizes(sizes);
+        }
+    }
+
+    void saveSplitterConfig()
+    {
+        if (mSideBar->isVisible()) {
+            GwenviewConfig::setSideBarSplitterSizes(mCentralSplitter->sizes());
+        }
+    }
+
     void setScreenSaverEnabled(bool enabled)
     {
         // Always delete mNotificationRestrictions, it does not hurt
@@ -774,7 +795,7 @@ struct MainWindow::Private
         if (!enabled) {
             mNotificationRestrictions = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver, q);
         } else {
-            mNotificationRestrictions = 0;
+            mNotificationRestrictions = nullptr;
         }
     }
 
@@ -782,7 +803,7 @@ struct MainWindow::Private
     {
         GV_RETURN_IF_FAIL(thumbnailView);
         if (mActiveThumbnailView) {
-            mActiveThumbnailView->setThumbnailProvider(0);
+            mActiveThumbnailView->setThumbnailProvider(nullptr);
         }
         thumbnailView->setThumbnailProvider(mThumbnailProvider);
         mActiveThumbnailView = thumbnailView;
@@ -819,9 +840,9 @@ MainWindow::MainWindow()
     d->setupThumbnailBarModel();
     d->mGvCore = new GvCore(this, d->mDirModel);
     d->mPreloader = new Preloader(this);
-    d->mNotificationRestrictions = 0;
+    d->mNotificationRestrictions = nullptr;
     d->mThumbnailProvider = new ThumbnailProvider();
-    d->mActiveThumbnailView = 0;
+    d->mActiveThumbnailView = nullptr;
     d->initDirModel();
     d->setupWidgets();
     d->setupActions();
@@ -1033,6 +1054,7 @@ void MainWindow::showStartMainPage()
     d->mCurrentMainPageId = StartMainPageId;
     d->setActionsDisabledOnStartMainPageEnabled(false);
 
+    d->saveSplitterConfig();
     d->mSideBar->hide();
     d->mViewStackedWidget->setCurrentWidget(d->mStartMainPage);
 
@@ -1110,6 +1132,7 @@ void MainWindow::folderViewUrlChanged(const QUrl &url) {
 
 void MainWindow::toggleSideBar(bool visible)
 {
+    d->saveSplitterConfig();
     d->mToggleSideBarAction->setChecked(visible);
     d->saveSideBarVisibility(visible);
     d->mSideBar->setVisible(visible);
@@ -1217,6 +1240,7 @@ void MainWindow::slotDirListerCompleted()
     } else {
         d->goToFirstDocument();
 
+        // Try to select the first directory in case there are no images to select
         if (!d->mContextManager->selectionModel()->hasSelection()) {
             const QModelIndex index = d->mThumbnailView->model()->index(0, 0);
             if (index.isValid()) {
@@ -1521,6 +1545,7 @@ void MainWindow::loadConfig()
     d->mBrowseMainPage->loadConfig();
     d->mContextManager->loadConfig();
     d->mSideBar->loadConfig();
+    d->loadSplitterConfig();
 }
 
 void MainWindow::saveConfig()
@@ -1529,6 +1554,7 @@ void MainWindow::saveConfig()
     d->mViewMainPage->saveConfig();
     d->mBrowseMainPage->saveConfig();
     d->mContextManager->saveConfig();
+    d->saveSplitterConfig();
     GwenviewConfig::setFullScreenModeActive(isFullScreen());
 }
 
@@ -1648,7 +1674,6 @@ void MainWindow::readProperties(const KConfigGroup& group)
 
     MainPageId pageId = MainPageId(group.readEntry(SESSION_CURRENT_PAGE_KEY, int(StartMainPageId)));
     if (pageId == StartMainPageId) {
-        d->mCurrentMainPageId = StartMainPageId;
         showStartMainPage();
     } else if (pageId == BrowseMainPageId) {
         d->mBrowseAction->trigger();
