@@ -36,6 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <KModelIndexProxyMapper>
 #include <KToggleAction>
 #include <KActivities/ResourceInstance>
+#include <KSqueezedTextLabel>
 
 // Local
 #include "fileoperations.h"
@@ -126,6 +127,7 @@ struct ViewMainPagePrivate
     KToggleAction* mToggleThumbnailBarAction;
     KToggleAction* mSynchronizeAction;
     QCheckBox* mSynchronizeCheckBox;
+    KSqueezedTextLabel* mDocumentCountLabel;
 
     // Activity Resource events reporting needs to be above KPart,
     // in the shell itself, to avoid problems with other MDI applications
@@ -237,6 +239,8 @@ struct ViewMainPagePrivate
         QObject::connect(view, &DocumentView::completed, q, &ViewMainPage::completed);
         QObject::connect(view, &DocumentView::previousImageRequested, q, &ViewMainPage::previousImageRequested);
         QObject::connect(view, &DocumentView::nextImageRequested, q, &ViewMainPage::nextImageRequested);
+        QObject::connect(view, &DocumentView::openUrlRequested, q, &ViewMainPage::openUrlRequested);
+        QObject::connect(view, &DocumentView::openDirUrlRequested, q, &ViewMainPage::openDirUrlRequested);
         QObject::connect(view, &DocumentView::captionUpdateRequested, q, &ViewMainPage::captionUpdateRequested);
         QObject::connect(view, &DocumentView::toggleFullScreenRequested, q, &ViewMainPage::toggleFullScreenRequested);
         QObject::connect(view, &DocumentView::focused, q, &ViewMainPage::slotViewFocused);
@@ -254,15 +258,15 @@ struct ViewMainPagePrivate
     void deleteDocumentView(DocumentView* view)
     {
         if (mDocumentViewController->view() == view) {
-            mDocumentViewController->setView(0);
+            mDocumentViewController->setView(nullptr);
         }
 
         // Make sure we do not get notified about this view while it is going away.
         // mDocumentViewController->deleteView() animates the view deletion so
         // the view still exists for a short while when we come back to the
         // event loop)
-        QObject::disconnect(view, 0, q, 0);
-        QObject::disconnect(view, 0, mSlideShow, 0);
+        QObject::disconnect(view, nullptr, q, nullptr);
+        QObject::disconnect(view, nullptr, mSlideShow, nullptr);
 
         mDocumentViews.removeOne(view);
         mActivityResources.remove(view);
@@ -282,6 +286,13 @@ struct ViewMainPagePrivate
         mZoomWidget = new ZoomWidget;
         mSynchronizeCheckBox = new QCheckBox(i18n("Synchronize"));
         mSynchronizeCheckBox->hide();
+        mDocumentCountLabel = new KSqueezedTextLabel;
+        mDocumentCountLabel->setAlignment(Qt::AlignCenter);
+        mDocumentCountLabel->setTextElideMode(Qt::ElideRight);
+        QMargins labelMargins = mDocumentCountLabel->contentsMargins();
+        labelMargins.setLeft(15);
+        labelMargins.setRight(15);
+        mDocumentCountLabel->setContentsMargins(labelMargins);
 
         QHBoxLayout* layout = new QHBoxLayout(mStatusBarContainer);
         layout->setMargin(0);
@@ -290,6 +301,9 @@ struct ViewMainPagePrivate
         layout->addWidget(mToggleThumbnailBarButton);
         layout->addStretch();
         layout->addWidget(mSynchronizeCheckBox);
+        // Ensure document count label takes up all available space,
+        // so its autohide feature works properly (stretch factor = 1)
+        layout->addWidget(mDocumentCountLabel, 1);
         layout->addStretch();
         layout->addWidget(mZoomWidget);
     }
@@ -374,9 +388,17 @@ struct ViewMainPagePrivate
 
     void applyPalette(bool fullScreenMode)
     {
-        mDocumentViewContainer->setPalette(mGvCore->palette(fullScreenMode ? GvCore::FullScreenViewPalette : GvCore::NormalViewPalette));
+        mDocumentViewContainer->applyPalette(mGvCore->palette(fullScreenMode ? GvCore::FullScreenViewPalette : GvCore::NormalViewPalette));
         setupThumbnailBarStyleSheet();
     }
+
+    void updateDocumentCountLabel()
+    {
+        const int current = mThumbnailBar->currentIndex().row() + 1;  // zero-based
+        const int total = mThumbnailBar->model()->rowCount();
+        const QString text = i18nc("@info:status %1 current document index, %2 total documents", "%1 of %2", current, total);
+        mDocumentCountLabel->setText(text);
+    }
 };
 
 ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollection* actionCollection, GvCore* gvCore)
@@ -384,7 +406,7 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
 , d(new ViewMainPagePrivate)
 {
     d->q = this;
-    d->mDirModelToBarModelProxyMapper = 0; // Initialized later
+    d->mDirModelToBarModelProxyMapper = nullptr; // Initialized later
     d->mSlideShow = slideShow;
     d->mActionCollection = actionCollection;
     d->mGvCore = gvCore;
@@ -424,6 +446,12 @@ ViewMainPage::ViewMainPage(QWidget* parent, SlideShow* slideShow, KActionCollect
     connect(d->mSynchronizeCheckBox, SIGNAL(toggled(bool)),
             d->mSynchronizeAction, SLOT(setChecked(bool)));
 
+    // Connections for the document count
+    connect(d->mThumbnailBar, &ThumbnailBarView::rowsInsertedSignal,
+            this, &ViewMainPage::slotDirModelItemsAddedOrRemoved);
+    connect(d->mThumbnailBar, &ThumbnailBarView::rowsRemovedSignal,
+            this, &ViewMainPage::slotDirModelItemsAddedOrRemoved);
+
     installEventFilter(this);
 }
 
@@ -595,7 +623,7 @@ bool ViewMainPage::isEmpty() const
 RasterImageView* ViewMainPage::imageView() const
 {
     if (!d->currentView()) {
-        return 0;
+        return nullptr;
     }
     return d->currentView()->imageView();
 }
@@ -692,6 +720,9 @@ void ViewMainPage::openUrls(const QList<QUrl>& allUrls, const QUrl &currentUrl)
     } else {
         d->mSynchronizer->setActive(false);
     }
+
+    d->updateDocumentCountLabel();
+    d->mDocumentCountLabel->setVisible(!d->mCompareMode);
 }
 
 void ViewMainPage::reload()
@@ -781,7 +812,7 @@ void ViewMainPage::trashView(DocumentView* view)
 
 void ViewMainPage::deselectView(DocumentView* view)
 {
-    DocumentView* newCurrentView = 0;
+    DocumentView* newCurrentView = nullptr;
     if (view == d->currentView()) {
         // We need to find a new view to set as current
         int idx = d->mDocumentViews.indexOf(view);
@@ -820,4 +851,9 @@ void ViewMainPage::updateFocus(const AbstractRasterImageViewTool* tool)
     }
 }
 
+void ViewMainPage::slotDirModelItemsAddedOrRemoved()
+{
+    d->updateDocumentCountLabel();
+}
+
 } // namespace
