@@ -44,8 +44,14 @@ public:
         UpdateIfNecessary,
         ForceUpdate
     };
+    enum AlphaBackgroundMode {
+        AlphaBackgroundNone,
+        AlphaBackgroundCheckBoard,
+        AlphaBackgroundSolid
+    };
+
     AbstractImageView(QGraphicsItem* parent);
-    ~AbstractImageView();
+    ~AbstractImageView() Q_DECL_OVERRIDE;
 
     qreal zoom() const;
 
@@ -57,7 +63,7 @@ public:
 
     virtual void setZoomToFit(bool value);
 
-    virtual void setZoomToFill(bool value);
+    virtual void setZoomToFill(bool value, const QPointF& center = QPointF(-1, -1));
 
     virtual void setDocument(Document::Ptr doc);
 
@@ -99,6 +105,8 @@ public:
 
     void applyPendingScrollPos();
 
+    void resetDragCursor();
+
 public Q_SLOTS:
     void updateCursor();
 
@@ -115,6 +123,10 @@ Q_SIGNALS:
     void toggleFullScreenRequested();
 
 protected:
+    virtual void setAlphaBackgroundMode(AlphaBackgroundMode mode) = 0;
+    virtual void setAlphaBackgroundColor(const QColor& color) = 0;
+    const QPixmap& alphaBackgroundTexture() const;
+
     virtual void loadFromDocument() = 0;
     virtual void onZoomChanged() = 0;
     /**
