@@ -31,15 +31,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsSceneWheelEvent>
+#include <QGraphicsOpacityEffect>
+#include <QGraphicsView>
 #include <QPainter>
 #include <QPropertyAnimation>
 #include <QPointer>
 #include <QDebug>
 #include <QIcon>
 #include <QUrl>
+#include <QDrag>
+#include <QMimeData>
+#include <QStyleHints>
 
 // KDE
 #include <KLocalizedString>
+#include <KFileItem>
+#include <KUrlMimeData>
 
 // Local
 #include <lib/document/document.h>
@@ -59,6 +66,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/gwenviewconfig.h>
 #include <lib/mimetypeutils.h>
 #include <lib/signalblocker.h>
+#include <lib/urlutils.h>
+#include <lib/thumbnailview/dragpixmapgenerator.h>
+#include <lib/thumbnailprovider/thumbnailprovider.h>
 
 namespace Gwenview
 {
@@ -90,6 +100,7 @@ struct DocumentViewPrivate
     BirdEyeView* mBirdEyeView;
     QPointer<QPropertyAnimation> mMoveAnimation;
     QPointer<QPropertyAnimation> mFadeAnimation;
+    QGraphicsOpacityEffect* mOpacityEffect;
 
     LoadingIndicator* mLoadingIndicator;
 
@@ -99,9 +110,12 @@ struct DocumentViewPrivate
     DocumentView::Setup mSetup;
     bool mCurrent;
     bool mCompareMode;
-    bool mEraseBorders;
     int controlWheelAccumulatedDelta;
 
+    QPointF mDragStartPosition;
+    QPointer<ThumbnailProvider> mDragThumbnailProvider;
+    QPointer<QDrag> mDrag;
+
     void setCurrentAdapter(AbstractDocumentViewAdapter* adapter)
     {
         Q_ASSERT(adapter);
@@ -322,8 +336,8 @@ struct DocumentViewPrivate
             }
         }
         // Create a new fade animation
-        QPropertyAnimation* anim = new QPropertyAnimation(q, "opacity");
-        anim->setStartValue(q->opacity());
+        QPropertyAnimation* anim = new QPropertyAnimation(mOpacityEffect, "opacity");
+        anim->setStartValue(mOpacityEffect->opacity());
         anim->setEndValue(value);
         if (qFuzzyCompare(value, 1)) {
             QObject::connect(anim, SIGNAL(finished()),
@@ -335,6 +349,88 @@ struct DocumentViewPrivate
         q->isAnimatedChanged();
         anim->start(QAbstractAnimation::DeleteWhenStopped);
     }
+
+    bool canPan() const
+    {
+        if (!q->canZoom()) {
+            return false;
+        }
+
+        const QSize zoomedImageSize = mDocument->size() * q->zoom();
+        const QSize viewPortSize = q->boundingRect().size().toSize();
+        const bool imageWiderThanViewport = zoomedImageSize.width() > viewPortSize.width();
+        const bool imageTallerThanViewport = zoomedImageSize.height() > viewPortSize.height();
+        return (imageWiderThanViewport || imageTallerThanViewport);
+    }
+
+    void setDragPixmap(const QPixmap& pix)
+    {
+        if (mDrag) {
+            DragPixmapGenerator::DragPixmap dragPixmap = DragPixmapGenerator::generate({pix}, 1);
+            mDrag->setPixmap(dragPixmap.pix);
+            mDrag->setHotSpot(dragPixmap.hotSpot);
+        }
+    }
+
+    void executeDrag()
+    {
+        if (mDrag) {
+            if (mAdapter->imageView()) {
+                mAdapter->imageView()->resetDragCursor();
+            }
+            mDrag->exec(Qt::MoveAction | Qt::CopyAction | Qt::LinkAction, Qt::CopyAction);
+        }
+    }
+
+    void initDragThumbnailProvider() {
+        mDragThumbnailProvider = new ThumbnailProvider();
+        QObject::connect(mDragThumbnailProvider, &ThumbnailProvider::thumbnailLoaded,
+                         q, &DocumentView::dragThumbnailLoaded);
+        QObject::connect(mDragThumbnailProvider, &ThumbnailProvider::thumbnailLoadingFailed,
+                         q, &DocumentView::dragThumbnailLoadingFailed);
+    }
+
+    void startDragIfSensible()
+    {
+        if (q->document()->loadingState() == Document::LoadingFailed) {
+            return;
+        }
+
+        if (q->currentTool()) {
+            return;
+        }
+
+        if (mDrag) {
+            mDrag->deleteLater();
+        }
+        mDrag = new QDrag(q);
+        const auto itemList = KFileItemList({q->document()->url()});
+        mDrag->setMimeData(MimeTypeUtils::selectionMimeData(itemList));
+
+        if (q->document()->isModified()) {
+            setDragPixmap(QPixmap::fromImage(q->document()->image()));
+            executeDrag();
+        } else {
+            // Drag is triggered on success or failure of thumbnail generation
+            if (mDragThumbnailProvider.isNull()) {
+                initDragThumbnailProvider();
+            }
+            mDragThumbnailProvider->appendItems(itemList);
+        }
+    }
+
+    QPointF cursorPosition() {
+        const QGraphicsScene* sc = q->scene();
+        if (sc) {
+            const auto views = sc->views();
+            for (const QGraphicsView* view : views) {
+                if (view->underMouse()) {
+                    return q->mapFromScene(view->mapFromGlobal(QCursor::pos()));
+                }
+            }
+        }
+        return QPointF(-1, -1);
+    }
 };
 
 DocumentView::DocumentView(QGraphicsScene* scene)
@@ -345,23 +441,35 @@ DocumentView::DocumentView(QGraphicsScene* scene)
     setFlag(ItemClipsChildrenToShape);
 
     d->q = this;
-    d->mLoadingIndicator = 0;
-    d->mBirdEyeView = 0;
+    d->mLoadingIndicator = nullptr;
+    d->mBirdEyeView = nullptr;
     d->mCurrent = false;
     d->mCompareMode = false;
-    d->mEraseBorders = false;
     d->controlWheelAccumulatedDelta = 0;
+    d->mDragStartPosition = QPointF(0, 0);
+    d->mDrag = nullptr;
 
-    setOpacity(0);
+    // We use an opacity effect instead of using the opacity property directly, because the latter operates at
+    // the painter level, which means if you draw multiple layers in paint(), all layers get the specified
+    // opacity, resulting in all layers being visible when 0 < opacity < 1.
+    // QGraphicsEffects on the other hand, operate after all painting is done, therefore 'flattening' all layers.
+    // This is important for fade effects, where we don't want any background layers visible during the fade.
+    d->mOpacityEffect = new QGraphicsOpacityEffect(this);
+    d->mOpacityEffect->setOpacity(0);
+    setGraphicsEffect(d->mOpacityEffect);
 
     scene->addItem(this);
 
     d->setupHud();
     d->setCurrentAdapter(new EmptyAdapter);
+
+    setAcceptDrops(true);
 }
 
 DocumentView::~DocumentView()
 {
+    delete d->mDragThumbnailProvider;
+    delete d->mDrag;
     delete d;
 }
 
@@ -373,7 +481,7 @@ void DocumentView::createAdapterForDocument()
         LOG("Reusing current adapter");
         return;
     }
-    AbstractDocumentViewAdapter* adapter = 0;
+    AbstractDocumentViewAdapter* adapter = nullptr;
     switch (documentKind) {
     case MimeTypeUtils::KIND_RASTER_IMAGE:
         adapter = new RasterImageViewAdapter;
@@ -405,7 +513,7 @@ void DocumentView::openUrl(const QUrl &url, const DocumentView::Setup& setup)
         if (url == d->mDocument->url()) {
             return;
         }
-        disconnect(d->mDocument.data(), 0, this, 0);
+        disconnect(d->mDocument.data(), nullptr, this, nullptr);
     }
     d->mSetup = setup;
     d->mDocument = DocumentFactory::instance()->load(url);
@@ -509,12 +617,28 @@ void DocumentView::setZoomToFit(bool on)
     d->mAdapter->setZoomToFit(on);
 }
 
+void DocumentView::toggleZoomToFit() {
+    const bool zoomToFitOn = d->mAdapter->zoomToFit();
+    d->mAdapter->setZoomToFit(!zoomToFitOn);
+    if (zoomToFitOn) {
+        d->setZoom(1., d->cursorPosition());
+    }
+}
+
 void DocumentView::setZoomToFill(bool on)
 {
     if (on == d->mAdapter->zoomToFill()) {
         return;
     }
-    d->mAdapter->setZoomToFill(on);
+    d->mAdapter->setZoomToFill(on, d->cursorPosition());
+}
+
+void DocumentView::toggleZoomToFill() {
+    const bool zoomToFillOn = d->mAdapter->zoomToFill();
+    d->mAdapter->setZoomToFill(!zoomToFillOn, d->cursorPosition());
+    if (zoomToFillOn) {
+        d->setZoom(1., d->cursorPosition());
+    }
 }
 
 bool DocumentView::zoomToFit() const
@@ -531,11 +655,14 @@ void DocumentView::zoomActualSize()
 {
     d->uncheckZoomToFit();
     d->uncheckZoomToFill();
-    d->mAdapter->setZoom(1.);
+    d->mAdapter->setZoom(1., d->cursorPosition());
 }
 
-void DocumentView::zoomIn(const QPointF& center)
+void DocumentView::zoomIn(QPointF center)
 {
+    if (center == QPointF(-1, -1)) {
+        center = d->cursorPosition();
+    }
     qreal currentZoom = d->mAdapter->zoom();
 
     Q_FOREACH(qreal zoom, d->mZoomSnapValues) {
@@ -546,8 +673,11 @@ void DocumentView::zoomIn(const QPointF& center)
     }
 }
 
-void DocumentView::zoomOut(const QPointF& center)
+void DocumentView::zoomOut(QPointF center)
 {
+    if (center == QPointF(-1, -1)) {
+        center = d->cursorPosition();
+    }
     qreal currentZoom = d->mAdapter->zoom();
 
     QListIterator<qreal> it(d->mZoomSnapValues);
@@ -584,6 +714,19 @@ void DocumentView::resizeEvent(QGraphicsSceneResizeEvent *event)
     QGraphicsWidget::resizeEvent(event);
 }
 
+void DocumentView::mousePressEvent(QGraphicsSceneMouseEvent* event)
+{
+    QGraphicsWidget::mousePressEvent(event);
+
+    if (d->mAdapter->canZoom() && event->button() == Qt::MiddleButton) {
+        if (event->modifiers() == Qt::NoModifier) {
+            toggleZoomToFit();
+        } else if (event->modifiers() == Qt::SHIFT) {
+            toggleZoomToFill();
+        }
+    }
+}
+
 void DocumentView::wheelEvent(QGraphicsSceneWheelEvent* event)
 {
     if (d->mAdapter->canZoom() && event->modifiers() & Qt::ControlModifier) {
@@ -633,21 +776,22 @@ void DocumentView::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
 
 void DocumentView::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget* /*widget*/)
 {
-    QRectF visibleRect = mapRectFromItem(d->mAdapter->widget(), d->mAdapter->visibleDocumentRect());
-    if (d->mEraseBorders) {
-        QRegion borders = QRegion(boundingRect().toRect())
-            - QRegion(visibleRect.toRect());
-        Q_FOREACH(const QRect& rect, borders.rects()) {
-            painter->eraseRect(rect);
-        }
-    }
+    // Fill background manually, because setAutoFillBackground(true) fill with QPalette::Window,
+    // but our palettes use QPalette::Base for the background color/texture
+    painter->fillRect(rect(), palette().base());
 
+    // Selection indicator/highlight
     if (d->mCompareMode && d->mCurrent) {
         painter->save();
         painter->setBrush(Qt::NoBrush);
         painter->setPen(QPen(palette().highlight().color(), 2));
         painter->setRenderHint(QPainter::Antialiasing);
-        QRectF selectionRect = visibleRect.adjusted(-2, -2, 2, 2);
+        const QRectF visibleRectF = mapRectFromItem(d->mAdapter->widget(), d->mAdapter->visibleDocumentRect());
+        // Round the point and size independently. This is different than calling toRect(),
+        // and is necessary to keep consistent rects, otherwise the selection rect can be
+        // drawn 1 pixel too big or small.
+        const QRect visibleRect = QRect(visibleRectF.topLeft().toPoint(), visibleRectF.size().toSize());
+        const QRect selectionRect = visibleRect.adjusted(-1, -1, 1, 1);
         painter->drawRoundedRect(selectionRect, 3, 3);
         painter->restore();
     }
@@ -784,18 +928,29 @@ bool DocumentView::isAnimated() const
 bool DocumentView::sceneEventFilter(QGraphicsItem*, QEvent* event)
 {
     if (event->type() == QEvent::GraphicsSceneMousePress) {
+        const QGraphicsSceneMouseEvent* mouseEvent = static_cast<QGraphicsSceneMouseEvent*>(event);
+        if (mouseEvent->button() == Qt::LeftButton) {
+            d->mDragStartPosition = mouseEvent->pos();
+        }
         QMetaObject::invokeMethod(this, "emitFocused", Qt::QueuedConnection);
     } else if (event->type() == QEvent::GraphicsSceneHoverMove) {
         if (d->mBirdEyeView) {
             d->mBirdEyeView->onMouseMoved();
         }
+    } else if (event->type() == QEvent::GraphicsSceneMouseMove) {
+        const QGraphicsSceneMouseEvent* mouseEvent = static_cast<QGraphicsSceneMouseEvent*>(event);
+        const qreal dragDistance = (mouseEvent->pos() - d->mDragStartPosition).manhattanLength();
+        const qreal minDistanceToStartDrag = QGuiApplication::styleHints()->startDragDistance();
+        if (!d->canPan() && dragDistance >= minDistanceToStartDrag) {
+            d->startDragIfSensible();
+        }
     }
     return false;
 }
 
 AbstractRasterImageViewTool* DocumentView::currentTool() const
 {
-    return imageView() ? imageView()->currentTool() : 0;
+    return imageView() ? imageView()->currentTool() : nullptr;
 }
 
 int DocumentView::sortKey() const
@@ -808,15 +963,53 @@ void DocumentView::setSortKey(int sortKey)
     d->mSortKey = sortKey;
 }
 
-void DocumentView::setEraseBorders(bool value)
-{
-    d->mEraseBorders = value;
-}
-
 void DocumentView::hideAndDeleteLater()
 {
     hide();
     deleteLater();
 }
 
+void DocumentView::setGraphicsEffectOpacity(qreal opacity)
+{
+    d->mOpacityEffect->setOpacity(opacity);
+}
+
+void DocumentView::dragEnterEvent(QGraphicsSceneDragDropEvent* event)
+{
+    QGraphicsWidget::dragEnterEvent(event);
+
+    const auto urls = KUrlMimeData::urlsFromMimeData(event->mimeData());
+    bool acceptDrag = !urls.isEmpty();
+    if (urls.size() == 1 && urls.first() == url()) {
+        // Do not allow dragging a single image onto itself
+        acceptDrag = false;
+    }
+    event->setAccepted(acceptDrag);
+}
+
+void DocumentView::dropEvent(QGraphicsSceneDragDropEvent* event)
+{
+    QGraphicsWidget::dropEvent(event);
+    // Since we're capturing drops in View mode, we only support one url
+    const QUrl url = event->mimeData()->urls().first();
+    if (UrlUtils::urlIsDirectory(url)) {
+        emit openDirUrlRequested(url);
+    } else {
+        emit openUrlRequested(url);
+    }
+}
+
+void DocumentView::dragThumbnailLoaded(const KFileItem& item, const QPixmap& pix)
+{
+    d->setDragPixmap(pix);
+    d->executeDrag();
+    d->mDragThumbnailProvider->removeItems(KFileItemList({item}));
+}
+
+void DocumentView::dragThumbnailLoadingFailed(const KFileItem& item)
+{
+    d->executeDrag();
+    d->mDragThumbnailProvider->removeItems(KFileItemList({item}));
+}
+
 } // namespace
