@@ -81,8 +81,8 @@ public:
      * Create a new view attached to scene. We need the scene to be able to
      * install scene event filters.
      */
-    DocumentView(QGraphicsScene* scene);
-    ~DocumentView();
+    explicit DocumentView(QGraphicsScene* scene);
+    ~DocumentView() Q_DECL_OVERRIDE;
 
     Document::Ptr document() const;
 
@@ -134,20 +134,22 @@ public:
     int sortKey() const;
     void setSortKey(int sortKey);
 
-    /**
-     * If true, areas around the document will be painted with the default brush.
-     * If false they will be kept transparent.
-     */
-    void setEraseBorders(bool);
-
     bool isAnimated() const;
 
+    /**
+     * Sets the opacity on the installed QGraphicsOpacityEffect.
+     * Use this instead of setOpacity().
+     */
+    void setGraphicsEffectOpacity(qreal opacity);
+
 public Q_SLOTS:
     void setZoom(qreal);
 
     void setZoomToFit(bool);
+    void toggleZoomToFit();
 
     void setZoomToFill(bool);
+    void toggleZoomToFill();
 
     void setPosition(const QPoint&);
 
@@ -163,6 +165,10 @@ Q_SIGNALS:
 
     void nextImageRequested();
 
+    void openUrlRequested(const QUrl&);
+
+    void openDirUrlRequested(const QUrl&);
+
     void captionUpdateRequested(const QString&);
 
     void toggleFullScreenRequested();
@@ -195,12 +201,15 @@ Q_SIGNALS:
     void isAnimatedChanged();
 
 protected:
-    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0) Q_DECL_OVERRIDE;
+    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = nullptr) Q_DECL_OVERRIDE;
 
     void resizeEvent(QGraphicsSceneResizeEvent* event) Q_DECL_OVERRIDE;
+    void mousePressEvent(QGraphicsSceneMouseEvent* event) Q_DECL_OVERRIDE;
     void wheelEvent(QGraphicsSceneWheelEvent* event) Q_DECL_OVERRIDE;
     void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) Q_DECL_OVERRIDE;
     bool sceneEventFilter(QGraphicsItem*, QEvent*) Q_DECL_OVERRIDE;
+    void dragEnterEvent(QGraphicsSceneDragDropEvent* event) override;
+    void dropEvent(QGraphicsSceneDragDropEvent* event) override;
 
 private Q_SLOTS:
     void finishOpenUrl();
@@ -209,8 +218,8 @@ private Q_SLOTS:
 
     void zoomActualSize();
 
-    void zoomIn(const QPointF& center = QPointF(-1, -1));
-    void zoomOut(const QPointF& center = QPointF(-1, -1));
+    void zoomIn(QPointF center = QPointF(-1, -1));
+    void zoomOut(QPointF center = QPointF(-1, -1));
 
     void slotZoomChanged(qreal);
 
@@ -222,6 +231,9 @@ private Q_SLOTS:
 
     void slotFadeInFinished();
 
+    void dragThumbnailLoaded(const KFileItem&, const QPixmap&);
+    void dragThumbnailLoadingFailed(const KFileItem&);
+
 private:
     friend struct DocumentViewPrivate;
     DocumentViewPrivate* const d;
