@@ -44,11 +44,10 @@ struct RasterImageViewPrivate
 {
     RasterImageView* q;
     ImageScaler* mScaler;
-    QPixmap mBackgroundTexture;
     bool mEmittedCompleted;
 
     // Config
-    RasterImageView::AlphaBackgroundMode mAlphaBackgroundMode;
+    AbstractImageView::AlphaBackgroundMode mAlphaBackgroundMode;
     QColor mAlphaBackgroundColor;
     cmsUInt32Number mRenderingIntent;
     bool mEnlargeSmallerImages;
@@ -75,7 +74,7 @@ struct RasterImageViewPrivate
         if (mDisplayTransform) {
             cmsDeleteTransform(mDisplayTransform);
         }
-        mDisplayTransform = 0;
+        mDisplayTransform = nullptr;
 
         Cms::Profile::Ptr profile = q->document()->cmsProfile();
         if (!profile) {
@@ -111,16 +110,6 @@ struct RasterImageViewPrivate
         mApplyDisplayTransform = true;
     }
 
-    void createBackgroundTexture()
-    {
-        mBackgroundTexture = QPixmap(32, 32);
-        QPainter painter(&mBackgroundTexture);
-        painter.fillRect(mBackgroundTexture.rect(), QColor(128, 128, 128));
-        QColor light = QColor(192, 192, 192);
-        painter.fillRect(0, 0, 16, 16, light);
-        painter.fillRect(16, 16, 16, 16, light);
-    }
-
     void setupUpdateTimer()
     {
         mUpdateTimer = new QTimer(q);
@@ -173,19 +162,28 @@ struct RasterImageViewPrivate
         mAlternateBuffer = QPixmap();
     }
 
-    void drawAlphaBackground(QPainter* painter, const QRect& viewportRect, const QPoint& zoomedImageTopLeft)
+    void drawAlphaBackground(QPainter* painter, const QRect& viewportRect, const QPoint& zoomedImageTopLeft, QPixmap texture)
     {
-        if (mAlphaBackgroundMode == RasterImageView::AlphaBackgroundCheckBoard) {
-            QPoint textureOffset(
-                zoomedImageTopLeft.x() % mBackgroundTexture.width(),
-                zoomedImageTopLeft.y() % mBackgroundTexture.height()
-            );
-            painter->drawTiledPixmap(
-                viewportRect,
-                mBackgroundTexture,
-                textureOffset);
-        } else {
-            painter->fillRect(viewportRect, mAlphaBackgroundColor);
+        switch (mAlphaBackgroundMode) {
+            case AbstractImageView::AlphaBackgroundNone:
+                painter->fillRect(viewportRect, Qt::transparent);
+                break;
+            case AbstractImageView::AlphaBackgroundCheckBoard:
+            {
+                const QPoint textureOffset(
+                    zoomedImageTopLeft.x() % texture.width(),
+                    zoomedImageTopLeft.y() % texture.height());
+                painter->drawTiledPixmap(
+                    viewportRect,
+                    texture,
+                    textureOffset);
+                break;
+            }
+            case AbstractImageView::AlphaBackgroundSolid:
+                painter->fillRect(viewportRect, mAlphaBackgroundColor);
+                break;
+            default:
+                Q_ASSERT(0);
         }
     }
 };
@@ -197,9 +195,9 @@ RasterImageView::RasterImageView(QGraphicsItem* parent)
     d->q = this;
     d->mEmittedCompleted = false;
     d->mApplyDisplayTransform = true;
-    d->mDisplayTransform = 0;
+    d->mDisplayTransform = nullptr;
 
-    d->mAlphaBackgroundMode = AlphaBackgroundCheckBoard;
+    d->mAlphaBackgroundMode = AlphaBackgroundNone;
     d->mAlphaBackgroundColor = Qt::black;
     d->mRenderingIntent = INTENT_PERCEPTUAL;
     d->mEnlargeSmallerImages = false;
@@ -208,7 +206,6 @@ RasterImageView::RasterImageView(QGraphicsItem* parent)
     d->mScaler = new ImageScaler(this);
     connect(d->mScaler, &ImageScaler::scaledRect, this, &RasterImageView::updateFromScaler);
 
-    d->createBackgroundTexture();
     d->setupUpdateTimer();
 }
 
@@ -346,13 +343,15 @@ void RasterImageView::updateFromScaler(int zoomedImageLeft, int zoomedImageTop,
     d->mBufferIsEmpty = false;
     {
         QPainter painter(&d->mCurrentBuffer);
+        painter.setCompositionMode(QPainter::CompositionMode_Source);
         if (document()->hasAlphaChannel()) {
             d->drawAlphaBackground(
                 &painter, QRect(viewportLeft, viewportTop, image.width(), image.height()),
-                QPoint(zoomedImageLeft, zoomedImageTop)
+                QPoint(zoomedImageLeft, zoomedImageTop),
+                alphaBackgroundTexture()
             );
-        } else {
-            painter.setCompositionMode(QPainter::CompositionMode_Source);
+            // This is required so transparent pixels don't replace our background
+            painter.setCompositionMode(QPainter::CompositionMode_SourceOver);
         }
         painter.drawImage(viewportLeft, viewportTop, image);
     }
@@ -368,7 +367,7 @@ void RasterImageView::onZoomChanged()
 {
     // If we zoom more than twice, then assume the user wants to see the real
     // pixels, for example to fine tune a crop operation
-    if (zoom() < 2.) {
+    if (zoom() < 4.) {
         d->mScaler->setTransformationMode(Qt::SmoothTransformation);
     } else {
         d->mScaler->setTransformationMode(Qt::FastTransformation);
@@ -392,6 +391,7 @@ void RasterImageView::onScrollPosChanged(const QPointF& oldPos)
         if (d->mAlternateBuffer.size() != d->mCurrentBuffer.size()) {
             d->mAlternateBuffer = QPixmap(d->mCurrentBuffer.size());
         }
+        d->mAlternateBuffer.fill(Qt::transparent);
         QPainter painter(&d->mAlternateBuffer);
         painter.drawPixmap(-delta, d->mCurrentBuffer);
     }
@@ -411,10 +411,11 @@ void RasterImageView::paint(QPainter* painter, const QStyleOptionGraphicsItem* /
         // In zoomToFit mode, scale crudely the buffer to fit the screen. This
         // provide an approximate rendered which will be replaced when the scheduled
         // proper scale is ready.
-        QSizeF size = documentSize() * zoom();
-        painter->drawPixmap(topLeft.x(), topLeft.y(), size.width(), size.height(), d->mCurrentBuffer);
+        // Round point and size independently, to keep consistency with the below (non zoomToFit) painting
+        const QRect rect = QRect(topLeft.toPoint(), (documentSize() * zoom()).toSize());
+        painter->drawPixmap(rect, d->mCurrentBuffer);
     } else {
-        painter->drawPixmap(topLeft, d->mCurrentBuffer);
+        painter->drawPixmap(topLeft.toPoint(), d->mCurrentBuffer);
     }
 
     if (d->mTool) {
