@@ -678,16 +678,22 @@ bool ThumbnailView::isBusy(const QModelIndex& index) const
     return d->mDocumentInfoProvider->isBusy(url);
 }
 
-void ThumbnailView::startDrag(Qt::DropActions supportedActions)
+void ThumbnailView::startDrag(Qt::DropActions)
 {
-    QModelIndexList indexes = selectionModel()->selectedIndexes();
+    const QModelIndexList indexes = selectionModel()->selectedIndexes();
     if (indexes.isEmpty()) {
         return;
     }
+
+    KFileItemList selectedFiles;
+    for (const auto index : indexes) {
+        selectedFiles << fileItemForIndex(index);
+    }
+
     QDrag* drag = new QDrag(this);
-    drag->setMimeData(model()->mimeData(indexes));
+    drag->setMimeData(MimeTypeUtils::selectionMimeData(selectedFiles));
     d->initDragPixmap(drag, indexes);
-    drag->exec(supportedActions, Qt::CopyAction);
+    drag->exec(Qt::MoveAction | Qt::CopyAction | Qt::LinkAction, Qt::CopyAction);
 }
 
 void ThumbnailView::dragEnterEvent(QDragEnterEvent* event)
